# hns_utils
Just some common helpful utility functions

## Installation
`pip install hns-utils`

## Import
`from hns_utils import <function_name>`

## Dependencies 
The functions here are for convenience. The packages required by 
them would need to be installed before a function can be used. If 
a function requires a third party package then that is listed in the 
docstring on the function. Install that package first and then use 
the function. 
